## 0.10.0.20250527 (2025-05-27)

[corus] set `no_longer_updated` (#14160)

Revert "Remove corus stubs" (#14158)

Remove corus stubs (#14153)

## 0.10.0.20250516 (2025-05-16)

Replace `Incomplete | None = None` in third party stubs (#14063)

## 0.10.0.20250413 (2025-04-13)

Import names from typing directly rather than importing module (#13761)

## 0.10.0.20250319 (2025-03-19)

[CI] Run stubtest with Python 3.13 (#13638)

## 0.10.0.20240814 (2024-08-14)

add baseline types for natasha-corus library of nlp sources (#12518)

